<?php
declare(strict_types=1);

namespace Catequil\Overseas\Model;

use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\Table;

/**
 * Class ApiKey
 *
 * @package Catequil\Overseas\Model
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-overseas
 */
#[Entity]
#[Table('overseas_apikey', options: ['collate' => 'utf8mb4_croatian_ci'])]
class ApiKey
{
    //<editor-fold desc="Entity Fields">

    #[Id]
    #[GeneratedValue('AUTO')]
    #[Column(type: Types::BIGINT, options: ['unsigned' => true])]
    protected ?int $id = null;
    #[Column(type: Types::STRING, length: 191, unique: true)]
    protected string $name = '';
    #[Column(type: Types::STRING)]
    protected string $testKey = '';
    #[Column(type: Types::STRING)]
    protected string $productionKey = '';
    #[Column(type: Types::BOOLEAN)]
    protected bool $testing = false;
    #[Column(type: Types::ARRAY)]
    protected array $documentTypes = [];
    #[Column(type: Types::ARRAY)]
    protected array $shippingMethods = [];
    #[Column(type: Types::ARRAY)]
    protected array $codPaymentMethods = [];

    //</editor-fold>
    //<editor-fold desc="Getters & Setters">

    /**
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return string
     */
    public function getTestKey(): string
    {
        return $this->testKey;
    }

    /**
     * @return string
     */
    public function getProductionKey(): string
    {
        return $this->productionKey;
    }

    /**
     * @return bool
     */
    public function isTesting(): bool
    {
        return $this->testing;
    }

    /**
     * @return array
     */
    public function getDocumentTypes(): array
    {
        return $this->documentTypes;
    }

    /**
     * @return array
     */
    public function getShippingMethods(): array
    {
        return $this->shippingMethods;
    }

    /**
     * @return array
     */
    public function getCodPaymentMethods(): array
    {
        return $this->codPaymentMethods;
    }

    //</editor-fold>
}